package com.weaver.seconddev.interfaces.workflow.action;

import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.esb.api.rpc.EsbServerlessRpcRemoteInterface;
import com.weaver.seconddev.interfaces.k3.CallK3SupplierServices;
import com.weaver.seconddev.interfaces.k3.SupplierServiceStub;
import com.weaver.verupgrade.soa.workflow.request.RequestInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author: calyrex
 * @CreateTime: 2025-01-17
 * @Description: K3_Get_SupplierInfo动作流调用
 */

@org.springframework.stereotype.Service("workflow_action_K3_Get_SupplierInfo_Action")
@Slf4j
public class K3_Get_SupplierInfo_Action implements EsbServerlessRpcRemoteInterface {

    @Autowired
    private RequestInfo requestInfoTemp;
    @Override
    public WeaResult<Map<String, Object>> execute(Map<String, Object> params) {
        log.error("K3_Get_SupplierInfo_Action execute start");
        log.error("K3_Get_SupplierInfo_Action execute params : " + params);
        try {
            String datacenterid = null2String(params.get("datacenterid")); //数据中心
            String  supname= null2String(params.get("supname")); //供应商名称
            String supnumber = null2String(params.get("supnumber")); //供应商编号
            String code = "0";
            String message = "";
            String issuccess = "";
            String result = "";
            SupplierServiceStub.SupplierSearchReq req = new SupplierServiceStub.SupplierSearchReq();
            req.setUser("oa");
            req.setPwd("k3cloud_htgd");
            req.setFName(supname);
            req.setFNumber(supnumber);
            req.setDataCenterID(datacenterid);
            CallK3SupplierServices services = new CallK3SupplierServices();
            SupplierServiceStub.SupplierReturn res = services.getSupplier(req);

            Map<String,Object> resultJson=new HashMap<>();
            resultJson.put("code",code);
            resultJson.put("message",message);
            resultJson.put("IsSuccess",issuccess);
            resultJson.put("result",result);
            SupplierServiceStub.Supplier supplier = res.getSupplier();
            Map<String,Object> supJson = new HashMap<>();
            if(supplier!=null){
                supJson.put("FSupName",supplier.getFSupName());//供应商名称
                supJson.put("FSupNumber",supplier.getFSupNumber());//公共上代码
                supJson.put("Fgroup",supplier.getFGroup());//供应商分组
                supJson.put("FGroupName",supplier.getFGroupName());//供应商分组名称
                supJson.put("FSupplierClassify",supplier.getFSupplierClassify());//供应商类别
                supJson.put("FSUPPLYCLASSIFYNAME",supplier.getFSUPPLYCLASSIFYNAME());//供应商类别名称
                supJson.put("SOCIALCRECODE",supplier.getFSOCIALCRECODE());//统一社会信用代码
                supJson.put("FPayCurrencyId",supplier.getFPayCurrencyId());//结算币别
                supJson.put("FPayCondition",supplier.getFPayCondition());//付款条件
                supJson.put("FTaxRateId",supplier.getFTaxRateId());//默认税率
                supJson.put("F_HTGD_RELATEDTYPE",supplier.getF_HTGD_RELATEDTYPE());//关联方属性
                SupplierServiceStub.ArrayOfOrganization org = supplier.getListOrgs();
                String orgcode = "";
                String orgname = "";
                if(org!=null){
                    SupplierServiceStub.Organization[] orgArr =  org.getOrganization();
                    if(orgArr!=null){
                        for(int m=0;m<orgArr.length;m++){
                            orgcode = orgcode + orgArr[m].getFNumber()+",";
                            orgname = orgname + orgArr[m].getFName()+",";
                        }
                        orgcode = orgcode.substring(0,orgcode.lastIndexOf(","));
                        orgname = orgname.substring(0,orgname.lastIndexOf(","));
                    }
                }

                supJson.put("orgcode",orgcode);//关联方属性
                supJson.put("orgname",orgname);//关联方属性
                //联系人信息
                SupplierServiceStub.SupContact contact = supplier.getSupContact();
                Map<String,Object> contactJson = new HashMap<>();
                if(contact!=null) {
                    contactJson.put("Fcontact", contact.getFCONTACT()); //联系人
                    contactJson.put("FBizAddress", contact.getFBIZADDRESS());//通讯地址
                    contactJson.put("FMobile", contact.getFMOBILE());//手机
                    contactJson.put("Ftel", contact.getFTEL());//电话
                    contactJson.put("FFax", contact.getFFAX());//传真
                    contactJson.put("Femail", contact.getFEMAIL());//电子邮箱
                }
                supJson.put("contact",contactJson);
                SupplierServiceStub.ArrayOfSupplierBank bankinfo =  supplier.getBankList();

                if(bankinfo!=null) {
                    SupplierServiceStub.SupplierBank[] bankarr = bankinfo.getSupplierBank();
                    List<Map<String,Object>> bankJsonarr = new ArrayList<>();
                    if(bankarr!=null && bankarr.length>0){
                        for (int i=0; i<bankarr.length;i++){
                            Map<String,Object> item = new HashMap<>();
                            item.put("FBankHolder",bankarr[i].getFBankHolder());
                            item.put("FBankCode",bankarr[i].getFBankCode());
                            item.put("FOPENBANKNAME",bankarr[i].getFOPENBANKNAME());
                            item.put("FCNAPS",bankarr[i].getFCNAPS());
                            bankJsonarr.add(item);
                        }
                    }
                    supJson.put("banklist",bankJsonarr);
                }else{
                    supJson.put("banklist",new ArrayList<>());
                }
            }
            resultJson.put("supplier",supJson);
            return WeaResult.success(resultJson);
        }catch (Exception e){
            log.error("K3_Get_SupplierInfo_Action execute error : " , e);
            return WeaResult.fail(500, "K3_Get_SupplierInfo_Action execute error", e);
        }
    }

    public static String null2String(String s){
        return s == null ? "" : s;
    }

    public static String null2String(Object o){
        return o == null ? "" : o.toString();
    }

    public static String null2String(String s1,String s2){
        return s1 == null ? (s2 == null ? "" : s2) : s1;
    }
}
