package com.weaver.seconddev.interfaces.workflow.controller;

import com.alibaba.fastjson.JSONObject;
import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.seconddev.interfaces.k3.CallK3SupplierServices;
import com.weaver.seconddev.interfaces.k3.SupplierServiceStub;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author: calyrex
 * @CreateTime: 2025-02-18
 * @Description: K3_Check_SupplierInfo的API调用
 */


@Slf4j
@RestController
@RequestMapping({"/papi/secondev/workflow/controller" })
public class K3_Check_SupplierInfo_controller {

    @Autowired
    private CallK3SupplierServices services;

    @RequestMapping("/K3_Check_SupplierInfo")
    public WeaResult<String> run(@RequestParam Map<String,Object> params) {
        log.error("K3_Check_SupplierInfo_controller execute start");
        log.error("K3_Check_SupplierInfo_controller execute params : " + params);
        try {
            String datacenterid = null2String(params.get("datacenterid")); //数据中心
            String  supname= null2String(params.get("supname")); //供应商名称
            String supnumber = null2String(params.get("supnumber")); //供应商编号
            String code = "0";
            String message = "";
            String issuccess = "";
            String result = "";
            SupplierServiceStub.SupplierSearchReq req = new SupplierServiceStub.SupplierSearchReq();
            req.setUser("oa");
            req.setPwd("k3cloud_htgd");
            req.setFName(supname);
            req.setFNumber(supnumber);
            req.setDataCenterID(datacenterid);
            SupplierServiceStub.SupplierSearchRes res = services.getSupMsg(req);
            code = res.getCode();
            message = res.getMessage();
            issuccess = res.getIsSuccess();
            result = res.getResult();


            JSONObject resultJson=new JSONObject();
            resultJson.put("code",code);
            resultJson.put("message",message);
            resultJson.put("IsSuccess",issuccess);
            resultJson.put("result",result);

            List<Map<String,Object>> suppliers = new ArrayList<>();

            if(code.equals("1")&&!result.equals("0")) {
                SupplierServiceStub.ArrayOfSupSample supsample = res.getSupSamples();
                SupplierServiceStub.SupSample[] arrs = supsample.getSupSample();
                if (arrs != null && arrs.length > 0) {
                    for (int i = 0; i < arrs.length; i++) {
                        Map<String,Object> item = new HashMap<>();
                        item.put("supname", arrs[i].getFSupName());
                        item.put("supnumber", arrs[i].getFSupNumber());
                        suppliers.add(item);
                    }
                }
            }
            resultJson.put("suppliers",suppliers);
            return WeaResult.success(JSONObject.toJSONString(resultJson));
        }catch (Exception e){
            log.error("K3_Check_SupplierInfo_controller execute error : " ,e);
            return WeaResult.fail(500, "K3_Check_SupplierInfo_controller execute error", e);
        }
    }

    public static String null2String(String s){
        return s == null ? "" : s;
    }

    public static String null2String(Object o){
        return o == null ? "" : o.toString();
    }

    public static String null2String(String s1,String s2){
        return s1 == null ? (s2 == null ? "" : s2) : s1;
    }
}
